summaryrefslogtreecommitdiffstats
path: root/src/java/com
diff options
context:
space:
mode:
authorSven Gothel <[email protected]>2011-09-28 12:56:54 +0200
committerSven Gothel <[email protected]>2011-09-28 12:56:54 +0200
commit110235691f8fda62b61256893d74f952dc596223 (patch)
tree2f4913afb29230445755b7ab9b8d0b182ccbc5a6 /src/java/com
parent3a323e52f92985f28ed44bf78557d5dfc38ab62e (diff)
Don't default to USE_TEMP_JAR_CACHE:=true on Android
Diffstat (limited to 'src/java/com')
-rw-r--r--src/java/com/jogamp/common/os/Platform.java5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/java/com/jogamp/common/os/Platform.java b/src/java/com/jogamp/common/os/Platform.java
index 6c582fb..8d93991 100644
--- a/src/java/com/jogamp/common/os/Platform.java
+++ b/src/java/com/jogamp/common/os/Platform.java
@@ -52,7 +52,8 @@ import jogamp.common.os.MachineDescriptionRuntime;
public class Platform {
/**
* System property: 'jogamp.gluegen.UseTempJarCache', defaults to true
*/
public static final boolean USE_TEMP_JAR_CACHE;
private static final String useTempJarCachePropName = "jogamp.gluegen.UseTempJarCache";
@@ -197,7 +198,7 @@ public class Platform {
os_and_arch = getOSAndArch(OS_TYPE, CPU_ARCH);
- USE_TEMP_JAR_CACHE =
+ USE_TEMP_JAR_CACHE = OS_TYPE != OSType.ANDROID &&
AccessController.doPrivileged(new PrivilegedAction<Boolean>() {
public Boolean run() {
return Boolean.valueOf(Debug.getBooleanProperty(true, useTempJarCachePropName, true, AccessController.getContext()));
@@ -52,7 +52,8 @@ import jogamp.common.os.MachineDescriptionRuntime;
public class Platform {
/**
- * System property: 'jogamp.gluegen.UseTempJarCache', defaults to true
+ * System property: 'jogamp.gluegen.UseTempJarCache',
+ * defaults to true if {@link #OS_TYPE} is not {@link OSType#ANDROID}.
*/
public static final boolean USE_TEMP_JAR_CACHE;